# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/phpdeveloper/phpdeveloper/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/phpdeveloper/phpdeveloper/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Phpdeveloper\\Phpdeveloper\\": "packages/phpdeveloper/phpdeveloper/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Phpdeveloper\Phpdeveloper\Providers\PhpdeveloperServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Phpdeveloper'  => Phpdeveloper\Phpdeveloper\Facades\Phpdeveloper::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Phpdeveloper\\PhpdeveloperTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Phpdeveloper\Phpdeveloper\Providers\PhpdeveloperServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Phpdeveloper\Phpdeveloper\Providers\PhpdeveloperServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Phpdeveloper\Phpdeveloper\Providers\PhpdeveloperServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/phpdeveloper/{modulename}

**User**

    http://path-to-route-folder/user/phpdeveloper/{modulename}

**Public**

    http://path-to-route-folder/phpdevelopers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/phpdeveloper/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/phpdeveloper/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/phpdeveloper/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/phpdeveloper/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/phpdeveloper/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/phpdeveloper/{modulename}/{slug}
    METHOD: GET