<?php

namespace Phpdeveloper\Phpdeveloper\Providers;

use Illuminate\Support\ServiceProvider;

class PhpdeveloperServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'phpdeveloper');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'phpdeveloper');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerPhpdeveloper();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerPhpdeveloper()
    {
        $this->app->bind('phpdeveloper', function($app) {
            return new Phpdeveloper($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Phpdeveloper', 'Lavalite\Phpdeveloper\Facades\Phpdeveloper');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('phpdeveloper.phpdeveloper', function ($app) {
            return $this->app->make('Phpdeveloper\Phpdeveloper\Phpdeveloper');
        });

                // Bind Phpdeveloper to repository
        $this->app->bind(
            'Phpdeveloper\Phpdeveloper\Interfaces\PhpdeveloperRepositoryInterface',
            \Phpdeveloper\Phpdeveloper\Repositories\Eloquent\PhpdeveloperRepository::class
        );

        $this->app->register(\Phpdeveloper\Phpdeveloper\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Phpdeveloper\Phpdeveloper\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and phpdeveloper's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'phpdeveloper.phpdeveloper'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakePhpdeveloper::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['phpdeveloper.phpdeveloper'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('phpdeveloper/phpdeveloper.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/phpdeveloper')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/phpdeveloper')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
